#
# spec file for package novnc
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           novnc
Version:        1.4.0
Release:        1.1
Summary:        VNC client using HTML5 (Web Sockets, Canvas) with encryption support
License:        LGPL-3.0-only AND MPL-2.0
Group:          System/Daemons
URL:            https://github.com/novnc/noVNC
Source0:        noVNC-%{version}.tar.gz
Patch1:         novnc-0.3-manpage.patch
Patch2:         novnc-1.4.0-fix-interpreter.patch
Requires:       python3-websockify >= 0.9.0
Requires:       which
BuildArch:      noarch

%description
This package provides a Websocket implementation of the VNC client.
It is used by OpenStack Horizon to provide a console view of running
instances.

%prep
%setup -q -n noVNC-%{version}
%autopatch -p1

%build

%install
mkdir -p %{buildroot}/%{_usr}/share/novnc/utils
install -m 444 *html %{buildroot}/%{_usr}/share/novnc
install -m 444 vnc.html %{buildroot}/%{_usr}/share/novnc/index.html
install -m 444 vnc_lite.html %{buildroot}/%{_usr}/share/novnc/vnc_auto.html

mkdir -p %{buildroot}/%{_usr}/share/novnc/app/
cp -rp app  %{buildroot}/%{_usr}/share/novnc

mkdir -p %{buildroot}/%{_usr}/share/novnc/core
cp -rp core  %{buildroot}/%{_usr}/share/novnc

mkdir -p %{buildroot}/%{_usr}/share/novnc/vendor
cp -rp vendor  %{buildroot}/%{_usr}/share/novnc

mkdir -p %{buildroot}/%{_bindir}
install utils/novnc_proxy  %{buildroot}/%{_bindir}/novnc_server

mkdir -p %{buildroot}%{_mandir}/man1/
install -m 444 docs/novnc_server.1 %{buildroot}%{_mandir}/man1/

%files
%license LICENSE.txt
%doc README.md
%{_bindir}/novnc_server
%{_datadir}/novnc/
%{_mandir}/man1/novnc_server.1%{?ext_man}

%changelog
* Thu Jan 26 2023 Manu Maier <mmanu84@outlook.de>
- Update to 1.4.0
    Library:
  * Secure context (https) is now required
  * Added support for the ZRLE encoding
  * Added support for RealVNC's JPEG encoding
  * Added support for Apple Remote Desktop's authentication
  * Added support for RealVNC's RSA-AES authentication
  * Added support for UltraVNC's MSLogonII authentication
- Renamed to patch novnc-1.3.0-fix-interpreter.patch to novnc-1.4.0-fix-interpreter.patch
* Sat Oct 29 2022 Software System <opensuse@wolke7.net>
- add "Requires: which" in case of missing running requirements
  in container environment.
  see https://github.com/novnc/noVNC/blob/f59be0586f675394514003784b7ffffbb845cc2b/utils/novnc_proxy#L170
* Fri Oct 22 2021 Manu Maier <mmanu84@outlook.de>
- Update to 1.3.0
    Application:
  * Added French and Portuguese (Brazil) translations
  * The novnc_proxy command (earlier launch.sh) is now able to interface better
    towards Websockify and now has it's own man page
    Library:
  * RTCDataChannel is now supported as a communication channel, an alternative
    to WebSockets
  * Resizes of the viewport are handled in a more modern way. This allows our
    library to not only react on browser window changes, but to size changes of
    the screen element as well
  * Fixed a bug with the Alt key on Firefox
  * Fixed a disconnect that happened when using some VNC servers. The error
    displayed in this case was "Error decoding rect: TypeError"
  * Plain authentication passwords now support longer passwords, which can be
    useful if you're using a password manager
  * Support for Internet Explorer has been dropped. This made it possible to use
    more modern features and clean up a large number of workarounds
- python3-websockify >= 0.9.0 is necessary
    https://github.com/novnc/noVNC/issues/1276#issuecomment-521174077
- Fix patch novnc-1.1.0-fix-interpreter.patch
  * Renamed to patch novnc-1.3.0-fix-interpreter.patch
* Tue Jul 14 2020 Manu Maier <mmanu84@outlook.de>
- Update to 1.2.0:
  * Quality and compression hints can now be modified dynamically
  * Added touch gestures to emulate common mouse actions
  * Support for full Unicode in clipboard
  * Support for VeNCrypt Plain authentication
  * Support for TightVNC Unix authentication
  * Support for alpha cursors
  * The session name is now updated whilst connected
* Sat Jul 20 2019 Manu Maier <mmanu84@outlook.de>
- Fix patch novnc-1.0.0-fix-interpreter.patch
  * Renamed to patch novnc-1.1.0-fix-interpreter.patch
- Update to 1.1.0:
  Application:
  * New translations for Russian, Korean, Czech and Chinese (traditional) languages
  * Fixed an issue where you didn't get scrollbars in your browser on Windows if
    you had a touch screen.
  * Added the Super/Windows key to the toolbar.
  * Added an option to show a dot when there otherwise wouldn't be a visible
    cursor.
  * View drag is no longer available when in scaling mode.
  Library:
  * A large number of coding style changes has been made to make the code easier
    to read and better to work with.
  * Many keyboard issues has been fixed.
  * Local cursor is now available on all platforms.
  * Fixed a number of crashes related to clipboard.
  * Fixed issues that occurred if data from the server was being received slowly.
  * A problem has been fixed where the display module would incorrectly handle
    high DPI systems causing scrollbars to show when they shouldn't.
* Wed Jan  2 2019 Dirk Mueller <dmueller@suse.com>
- require python3-websockify for recent distros (bsc#1119737)
* Wed Jun 20 2018 kberger@suse.com
  Fixes bugs bsc#1052286 and bsc#1077940
- Update to 1.0.0:
  _The first official stable release of noVNC is finally here._
  Lots of changes have been made since the last release, both in terms of features and bug fixes.
  Some of the more notable changes since the last release are:
  Application:
  Heavily revamped interface
  Everything is translated
  Automatic reconnect on disconnects
  Better handling of on screen keyboards
  Support for VNC "bell" sound
  Library:
  Cleaned up, official and stable API
  Converted to ES6 modules
  Much improved keyboard handling
  Support for QEMU's raw keyboard extension
  Support for continuous updates extension
  Proper handling of machines with both touch and mouse/trackpad
  Better handling of mouse wheels
  More responsive and performant panning
  Colour map mode is no longer supported
- Add novnc-0.3-manpage.patch
  novnc-0.3-manpage.patch: add manpage.
- Add novnc-1.0.0-fix-interpreter.patch
  novnc-1.0.0-fix-interpreter.patch: change shebang path from env to bash.
* Sat Jul 22 2017 dmueller@suse.com
- Update to 0.6.2:
  _This is a vulnerability fix release._
  Fixes a XSS issue in which the remote VNC server could inject
  arbitrary HTML into the noVNC web page via the messages propagated
  to the status field, such as the VNC server name.
  This affects users of vnc_auto.html and vnc.html, as well as any
  users of include/ui.js.
* Mon Dec  7 2015 dvaleev@suse.com
- Package is definetely noarch. Mark as such
* Mon Feb 16 2015 vuntz@suse.com
- Update to 0.5.1:
  + Improved keyboard support via use of keysyms.js
  + Fix HEXTILE "blank" tile support
  + lower minimum width to accommodate smaller screens
  + Fix issue causing true-color cursors to not be changed
  + Fix subprotocol support for the TIGHT encoding
- Changes from 0.5.0:
  + General Fixes/Improvements:
  - Use Object.defineProperty on Array prototype to prevent
    issues with enumeration
  - Internal Refactor for improved testability
  - Improved parsing of query string parameters
  - Support container page scrolling
  - Fixed IE10 keyboard support
  - Fixes for mobile keyboards (Android and iOS)
  - Improved foreign keyboard support
  - dynamic script loading without document.write
  + Protocol Support:
  - TightVNC support (we support choosing the NOTUNNEL type if
    tunnels are requested)
  - XVP Support
- Update license tag to "MPL-2.0; LGPL-3.0", following relicensing.
- Drop novnc-0.3-call-websockify.patch,
  novnc-0.3-nova-wsproxy.patch: not needed anymore.
* Tue Sep 24 2013 dmueller@suse.com
- update to 0.4:
  * Clarify permissive licenses of HTML, CSS, images.
  * Use render queue and requestAnimationFrame
  * UltraVNC repeater support
* Tue Mar 19 2013 berendt@b1-systems.de
- removed openstack-nova-novncproxy
* Wed Oct 10 2012 berendt@b1-systems.de
- make it buildable for SLES11 SP2
- import from Fedora 18
